@@ -101,7 +101,7 @@ exports.serve = function (nylon_path) {
         var options = {
             key: fs.readFileSync(work_dir + '/ssl/server.key'),
             cert: fs.readFileSync(work_dir + '/ssl/server.crt'),
-            spdy: {
+           /* spdy: {
                 protocols: ['h2', 'spdy/3.1', 'spdy/3', 'spdy/2', 'http/1.1', 'http/1.0'],
                 plain: false,
                 'x-forwarded-for': true,
@@ -109,7 +109,7 @@ exports.serve = function (nylon_path) {
                     windowSize: 1024 * 1024,
                     autoSpdy31: false
                 }
-            }
+            }*/
         };
 
         var server = http2.createServer(options, app);
